==> engauge-digitizer_8.3.orig.tar.gz: engauge-digitizer-8.3/src/Settings/Settings.h <==
/******************************************************************************************************
 * (C) 2014 markummitchell@github.com. This file is part of Engauge Digitizer, which is released      *
 * under GNU General Public License version 2 (GPLv2) or (at your option) any later version. See file *
 * LICENSE or go to gnu.org/licenses for details. Distribution requires prior written permission.     *
 ******************************************************************************************************/

#ifndef SETTINGS_H
#define SETTINGS_H

#include <QString>

// Settings tags for QSettings
extern const QString SETTINGS_BACKGROUND_IMAGE;
extern const QString SETTINGS_CHECKLIST_GUIDE_DOCK_AREA;
extern const QString SETTINGS_CHECKLIST_GUIDE_DOCK_GEOMETRY;
extern const QString SETTINGS_CHECKLIST_GUIDE_WIZARD;
extern const QString SETTINGS_CURRENT_DIRECTORY;
extern const QString SETTINGS_CURVE_LINE_COLOR;
extern const QString SETTINGS_CURVE_LINE_CONNECT_AS;
extern const QString SETTINGS_CURVE_LINE_WIDTH;
extern const QString SETTINGS_CURVE_NAME;
extern const QString SETTINGS_CURVE_POINT_COLOR;
extern const QString SETTINGS_CURVE_POINT_LINE_WIDTH;
extern const QString SETTINGS_CURVE_POINT_RADIUS;
extern const QString SETTINGS_CURVE_POINT_SHAPE;
extern const QString SETTINGS_DIGITIZER;
extern const QString SETTINGS_ENGAUGE;
extern const QString SETTINGS_EXPORT_CURVE_NAMES_NOT_EXPORTED;
extern const QString SETTINGS_EXPORT_DELIMITER;
extern const QString SETTINGS_EXPORT_DELIMITER_OVERRIDE_CSV_TSV;
extern const QString SETTINGS_EXPORT_HEADER;
extern const QString SETTINGS_EXPORT_LAYOUT_FUNCTIONS;
extern const QString SETTINGS_EXPORT_POINTS_INTERVAL_FUNCTIONS;
extern const QString SETTINGS_EXPORT_POINTS_INTERVAL_RELATIONS;
extern const QString SETTINGS_EXPORT_POINTS_INTERVAL_UNITS_FUNCTIONS;
extern const QString SETTINGS_EXPORT_POINTS_INTERVAL_UNITS_RELATIONS;
extern const QString SETTINGS_EXPORT_POINTS_SELECTION_FUNCTIONS;
extern const QString SETTINGS_EXPORT_POINTS_SELECTION_RELATIONS;
extern const QString SETTINGS_EXPORT_X_LABEL;
extern const QString SETTINGS_GENERAL_CURSOR_SIZE;
extern const QString SETTINGS_GENERAL_EXTRA_PRECISION;
extern const QString SETTINGS_GROUP_CURVE_AXES;
extern const QString SETTINGS_GROUP_CURVE_GRAPH;
extern const QString SETTINGS_GROUP_CURVE_GRAPH_PLACEHOLDER;
extern const QString SETTINGS_GROUP_ENVIRONMENT;
extern const QString SETTINGS_GROUP_EXPORT;
extern const QString SETTINGS_GROUP_GENERAL;
extern const QString SETTINGS_GROUP_IMPORT;
extern const QString SETTINGS_GROUP_MAIN_WINDOW;
extern const QString SETTINGS_GROUP_PDF;
extern const QString SETTINGS_HELP_POS;
extern const QString SETTINGS_HELP_SIZE;
extern const QString SETTINGS_IMPORT_PDF_RESOLUTION;
extern const QString SETTINGS_LOCALE_COUNTRY;
extern const QString SETTINGS_LOCALE_LANGUAGE;
extern const QString SETTINGS_MAIN_TITLE_BAR_FORMAT;
extern const QString SETTINGS_PDF_POS;
extern const QString SETTINGS_POS;
extern const QString SETTINGS_RECENT_FILE_LIST;
extern const QString SETTINGS_SIZE;
extern const QString SETTINGS_VIEW_BACKGROUND_TOOLBAR;
extern const QString SETTINGS_VIEW_COORD_SYSTEM_TOOLBAR;
extern const QString SETTINGS_VIEW_DIGITIZE_TOOLBAR;
extern const QString SETTINGS_VIEW_SETTINGS_VIEWS_TOOLBAR;
extern const QString SETTINGS_VIEW_STATUS_BAR;
extern const QString SETTINGS_VIEW_TOOL_TIPS;
extern const QString SETTINGS_ZOOM_CONTROL;
extern const QString SETTINGS_ZOOM_FACTOR;
extern const QString SETTINGS_ZOOM_FACTOR_INITIAL;

#endif // SETTINGS_H

==> engauge-digitizer-12.9.tar.gz: engauge-digitizer-12.9/src/Settings/Settings.h <==
/******************************************************************************************************
 * (C) 2014 markummitchell@github.com. This file is part of Engauge Digitizer, which is released      *
 * under GNU General Public License version 2 (GPLv2) or (at your option) any later version. See file *
 * LICENSE or go to gnu.org/licenses for details. Distribution requires prior written permission.     *
 ******************************************************************************************************/

#ifndef SETTINGS_H
#define SETTINGS_H

#include <QString>

// Settings tags for QSettings
extern const QString SETTINGS_BACKGROUND_IMAGE;
extern const QString SETTINGS_CHECKLIST_GUIDE_DOCK_AREA;
extern const QString SETTINGS_CHECKLIST_GUIDE_DOCK_GEOMETRY;
extern const QString SETTINGS_CHECKLIST_GUIDE_WIZARD;
extern const QString SETTINGS_CURRENT_DIRECTORY;
extern const QString SETTINGS_CURVE_LINE_COLOR;
extern const QString SETTINGS_CURVE_LINE_CONNECT_AS;
extern const QString SETTINGS_CURVE_LINE_WIDTH;
extern const QString SETTINGS_CURVE_NAME;
extern const QString SETTINGS_CURVE_POINT_COLOR;
extern const QString SETTINGS_CURVE_POINT_LINE_WIDTH;
extern const QString SETTINGS_CURVE_POINT_RADIUS;
extern const QString SETTINGS_CURVE_POINT_SHAPE;
extern const QString SETTINGS_DIGITIZER;
extern const QString SETTINGS_DRAG_DROP_EXPORT;
extern const QString SETTINGS_ENGAUGE;
extern const QString SETTINGS_EXPORT_CURVE_NAMES_NOT_EXPORTED;
extern const QString SETTINGS_EXPORT_DELIMITER;
extern const QString SETTINGS_EXPORT_DELIMITER_OVERRIDE_CSV_TSV;
extern const QString SETTINGS_EXPORT_EXTRAPOLATE_OUTSIDE_ENDPOINTS;
extern const QString SETTINGS_EXPORT_HEADER;
extern const QString SETTINGS_EXPORT_LAYOUT_FUNCTIONS;
extern const QString SETTINGS_EXPORT_POINTS_INTERVAL_FUNCTIONS;
extern const QString SETTINGS_EXPORT_POINTS_INTERVAL_RELATIONS;
extern const QString SETTINGS_EXPORT_POINTS_INTERVAL_UNITS_FUNCTIONS;
extern const QString SETTINGS_EXPORT_POINTS_INTERVAL_UNITS_RELATIONS;
extern const QString SETTINGS_EXPORT_POINTS_SELECTION_FUNCTIONS;
extern const QString SETTINGS_EXPORT_POINTS_SELECTION_RELATIONS;
extern const QString SETTINGS_EXPORT_X_LABEL;
extern const QString SETTINGS_FITTING_WINDOW_DOCK_AREA;
extern const QString SETTINGS_FITTING_WINDOW_DOCK_GEOMETRY;
extern const QString SETTINGS_GENERAL_CURSOR_SIZE;
extern const QString SETTINGS_GENERAL_EXTRA_PRECISION;
extern const QString SETTINGS_GEOMETRY_WINDOW_DOCK_AREA;
extern const QString SETTINGS_GEOMETRY_WINDOW_DOCK_GEOMETRY;
extern const QString SETTINGS_GROUP_CURVE_AXES;
extern const QString SETTINGS_GROUP_CURVE_GRAPH;
extern const QString SETTINGS_GROUP_CURVE_GRAPH_PLACEHOLDER;
extern const QString SETTINGS_GROUP_ENVIRONMENT;
extern const QString SETTINGS_GROUP_EXPORT;
extern const QString SETTINGS_GROUP_GENERAL;
extern const QString SETTINGS_GROUP_IMPORT;
extern const QString SETTINGS_GROUP_IMPORT_CROPPING;
extern const QString SETTINGS_GROUP_MAIN_WINDOW;
extern const QString SETTINGS_HELP_POS;
extern const QString SETTINGS_HELP_SIZE;
extern const QString SETTINGS_HIGHLIGHT_OPACITY;
extern const QString SETTINGS_IMAGE_REPLACE_RENAMES_DOCUMENT;
extern const QString SETTINGS_IMPORT_CROPPING;
extern const QString SETTINGS_IMPORT_CROPPING_POS;
extern const QString SETTINGS_IMPORT_PDF_RESOLUTION;
extern const QString SETTINGS_LOAD_VIEWS;
extern const QString SETTINGS_LOCALE_COUNTRY;
extern const QString SETTINGS_LOCALE_LANGUAGE;
extern const QString SETTINGS_MAIN_DIRECTORY_EXPORT_SAVE;
extern const QString SETTINGS_MAIN_DIRECTORY_IMPORT_LOAD;
extern const QString SETTINGS_MAIN_TITLE_BAR_FORMAT;
extern const QString SETTINGS_MAXIMUM_EXPORTED_POINTS_PER_CURVE;
extern const QString SETTINGS_MAXIMUM_GRID_LINES;
extern const QString SETTINGS_POS;
extern const QString SETTINGS_RECENT_FILE_LIST;
extern const QString SETTINGS_SIGNIFICANT_DIGITS;
extern const QString SETTINGS_SIZE;
extern const QString SETTINGS_SMALL_DIALOGS;
extern const QString SETTINGS_VIEW_BACKGROUND_TOOLBAR;
extern const QString SETTINGS_VIEW_COORD_SYSTEM_TOOLBAR;
extern const QString SETTINGS_VIEW_DIGITIZE_TOOLBAR;
extern const QString SETTINGS_VIEW_SETTINGS_VIEWS_TOOLBAR;
extern const QString SETTINGS_VIEW_STATUS_BAR;
extern const QString SETTINGS_VIEW_TOOL_TIPS;
extern const QString SETTINGS_ZOOM_CONTROL;
extern const QString SETTINGS_ZOOM_FACTOR;
extern const QString SETTINGS_ZOOM_FACTOR_INITIAL;

#endif // SETTINGS_H
